male_names = {
    "Ahmed": "أحمد", "Mohamed": "محمد", "Ali": "علي", "Omar": "عمر", "Youssef": "يوسف", "Ibrahim": "إبراهيم", "Hassan": "حسن", "Hussein": "حسين", "Khaled": "خالد", "Mahmoud": "محمود",
    "Mostafa": "مصطفى", "Amr": "عمرو", "Tamer": "تامر", "Karim": "كريم", "Samir": "سمير", "Sherif": "شريف", "Gamal": "جمال", "Ehab": "إيهاب", "Ashraf": "أشرف", "Adel": "عادل",
    "Sami": "سامي", "Tariq": "طارق", "Waleed": "وليد", "Hany": "هاني", "Saad": "سعد", "Fady": "فادي", "Bassem": "باسم", "Ezzat": "عزت", "Ramy": "رامي", "Nader": "نادر",
    "Marwan": "مروان", "Ayman": "أيمن", "Reda": "رضا", "Wael": "وائل", "Hesham": "هشام", "Sayed": "سيد", "Shady": "شادي", "Ziad": "زياد", "Magdy": "مجدي", "Lotfy": "لطفي",
    "Medhat": "مدحت", "Kareem": "كريم", "Yasser": "ياسر", "Fouad": "فؤاد", "Anwar": "أنور", "Gaber": "جابر", "Shokry": "شكري", "Salah": "صلاح", "Mostafa": "مصطفى", "Bahaa": "بهاء",
    "Ismail": "إسماعيل", "Hamdy": "حمدي", "Shawky": "شوقي", "Emad": "عماد", "Osama": "أسامة", "Hatem": "حاتم", "Nabil": "نبيل", "Lotfi": "لطفي", "Alaa": "علاء", "Sameh": "سامح",
    "Fathi": "فتحي", "Farid": "فريد", "Bassel": "باسل", "Ehab": "إيهاب", "Sabry": "صبري", "Sayed": "سيد", "Shereef": "شريف", "Essam": "عصام", "Sherbini": "الشربيني", "Ragab": "رجب",
    "Hany": "هاني", "Bishoy": "بيشوي", "Mina": "مينا", "Victor": "فيكتور", "Adham": "أدهم", "Tawfiq": "توفيق", "Hamza": "حمزة", "Saif": "سيف", "Fares": "فارس", "Moataz": "معتز",
    "Wahid": "وحيد", "Ihab": "إيهاب", "Nashaat": "نشأت", "Galal": "جلال", "Hady": "هادي", "Salem": "سالم", "Sherif": "شريف", "Emam": "إمام", "Refaat": "رفعت", "Bakr": "بكر",
    "Mamdouh": "ممدوح", "Montaser": "منتصر", "Abdelrahman": "عبد الرحمن", "Saber": "صابر", "Makram": "مكرم", "Gerges": "جرجس", "Eid": "عيد", "Fawzy": "فوزي", "Anas": "أنس", "Raouf": "رؤوف"
}
female_names = {
    "Amina": "أمينة", "Fatma": "فاطمة", "Nour": "نور", "Mona": "منى", "Dina": "دينا", "Heba": "هبة", "Samar": "سمر", "Marwa": "مروة", "Rania": "رانيا", "Yasmin": "ياسمين",
    "Nadia": "نادية", "Layla": "ليلى", "Hanan": "حنان", "Nihal": "نهال", "Nagwa": "نجوى", "Zahraa": "زهراء", "Sarah": "سارة", "Maha": "مها", "Noha": "نهى", "Doaa": "دعاء",
    "Abeer": "عبير", "Shimaa": "شيماء", "Eman": "إيمان", "Riham": "ريهام", "Ghada": "غادة", "Mervat": "مرفت", "Walaa": "ولاء", "Sally": "سالي", "Hadeer": "هدير", "Mai": "مي",
    "Shaimaa": "شيماء", "Esraa": "إسراء", "Amal": "أمل", "Lobna": "لبنى", "Nourhan": "نورهان", "Dalia": "داليا", "Hind": "هند", "Karima": "كريمة", "Rasha": "رشا", "Ruqayya": "رقية",
    "Nahla": "نهلة", "Bassma": "بسمة", "Maram": "مرام", "Rehab": "رحاب", "Manar": "منار", "Huda": "هدى", "Nermine": "نرمين", "Hagar": "هاجر", "Sahar": "سحر", "Ferial": "فريال",
    "Lubna": "لبنى", "Basma": "بسمة", "Mariam": "مريم", "Randa": "راندا", "Salma": "سلمى", "Tahani": "تهاني", "Zeinab": "زينب", "Asmaa": "أسماء", "Gihan": "جيهان", "Samia": "سامية",
    "Wafaa": "وفاء", "Sondos": "سندس", "Hala": "هالة", "Sabah": "صباح", "Yosra": "يسرا", "Dorra": "درة", "Rim": "ريم", "Rania": "رانيا", "Elham": "إلهام", "Hanadi": "هنادي",
    "Rawan": "روان", "Lamia": "لمياء", "Reem": "ريم", "Rokaya": "رقية", "Suhair": "سهير", "Sherine": "شيرين", "Zina": "زينة", "Fawzia": "فوزية", "Sahar": "سحر", "Lina": "لينا",
    "Ahlam": "أحلام", "Mariana": "ماريانا", "Maysa": "ميساء", "Fadia": "فادية", "Ghada": "غادة", "Najla": "نجلاء", "Iman": "إيمان", "Salsabil": "سلسبيل", "Afaf": "عفاف", "Rimonda": "ريموندا",
    "Malak": "ملك", "Esraa": "إسراء", "Jana": "جنى", "Laila": "ليلى", "Rasha": "رشا", "Mirna": "ميرنا", "Dalida": "داليدا", "Khadija": "خديجة", "Sondos": "سندس", "Yasmina": "ياسمينة"
}
male_job_titles = {
    "Engineer": "مهندس", "Doctor": "طبيب", "Teacher": "معلم", "Accountant": "محاسب", "Lawyer": "محام", "Architect": "مهندس معماري", "Pharmacist": "صيدلي", "Journalist": "صحفي", "Dentist": "طبيب أسنان", "Electrician": "كهربائي",
    "Plumber": "سباك", "Carpenter": "نجار", "Mechanic": "ميكانيكي", "Chef": "طاهٍ", "Driver": "سائق", "Pilot": "طيار", "Soldier": "جندي", "Police Officer": "ضابط شرطة", "Firefighter": "رجل إطفاء", "Scientist": "عالم",
    "Professor": "أستاذ جامعي", "Researcher": "باحث", "Economist": "اقتصادي", "Psychologist": "طبيب نفسي", "Therapist": "معالج", "Veterinarian": "طبيب بيطري", "Artist": "فنان", "Musician": "موسيقي", "Actor": "ممثل", "Director": "مخرج",
    "Photographer": "مصور", "Designer": "مصمم", "Writer": "كاتب", "Editor": "محرر", "Translator": "مترجم", "IT Specialist": "أخصائي تكنولوجيا المعلومات", "Software Developer": "مطور برمجيات", "Web Developer": "مطوّر ويب", "Graphic Designer": "مصمم جرافيك", "Data Analyst": "محلل بيانات",
    "Statistician": "إحصائي", "Cybersecurity Analyst": "محلل أمن سيبراني", "Network Engineer": "مهندس شبكات", "System Administrator": "مسؤول أنظمة", "Marketing Specialist": "أخصائي تسويق", "Sales Manager": "مدير مبيعات", "HR Specialist": "أخصائي موارد بشرية", "Consultant": "مستشار", "Banker": "موظف بنك", "Financial Analyst": "محلل مالي",
    "Investment Manager": "مدير استثمار", "Stockbroker": "سمسار بورصة", "Insurance Agent": "وكيل تأمين", "Auditor": "مدقق حسابات", "Public Relations Specialist": "أخصائي علاقات عامة", "Event Planner": "منظم فعاليات", "Tour Guide": "مرشد سياحي", "Hotel Manager": "مدير فندق", "Waiter": "نادل", "Baker": "خباز",
    "Butcher": "جزار", "Fisherman": "صياد", "Farmer": "مزارع", "Construction Worker": "عامل بناء", "Real Estate Agent": "وكيل عقارات", "Security Guard": "حارس أمن", "Janitor": "عامل نظافة", "Tailor": "خياط", "Shoemaker": "إسكافي", "Barber": "حلاق",
    "Flight Attendant": "مضيف طيران", "Ship Captain": "قبطان سفينة", "Athlete": "رياضي", "Coach": "مدرب", "Referee": "حكم", "Gym Trainer": "مدرب رياضي", "Priest": "قسيس", "Imam": "إمام", "Monk": "راهب", "Social Worker": "أخصائي اجتماعي",
    "Volunteer": "متطوع", "Judge": "قاضٍ", "Politician": "سياسي", "Ambassador": "سفير", "Diplomat": "دبلوماسي", "Government Officer": "موظف حكومي", "Entrepreneur": "رائد أعمال", "Business Owner": "صاحب عمل", "Manager": "مدير", "Supervisor": "مشرف",
    "Clerk": "كاتب", "Receptionist": "موظف استقبال", "Courier": "ساعٍ", "Delivery Driver": "سائق توصيل", "Warehouse Worker": "عامل مستودع", "Logistics Coordinator": "منسق لوجستي"
}
female_job_titles = {
    "Engineer": "مهندسة", "Doctor": "طبيبة", "Teacher": "معلمة", "Accountant": "محاسبة", "Lawyer": "محامية", "Architect": "مهندسة معمارية", "Pharmacist": "صيدلانية", "Journalist": "صحفية", "Dentist": "طبيبة أسنان", "Electrician": "كهربائية",
    "Plumber": "سباكة", "Carpenter": "نجارة", "Mechanic": "ميكانيكية", "Chef": "طاهية", "Driver": "سائقة", "Pilot": "طيارة", "Soldier": "جندية", "Police Officer": "ضابطة شرطة", "Firefighter": "إطفائية", "Scientist": "عالمة",
    "Professor": "أستاذة جامعية", "Researcher": "باحثة", "Economist": "اقتصادية", "Psychologist": "طبيبة نفسية", "Therapist": "معالجة", "Veterinarian": "طبيبة بيطرية", "Artist": "فنانة", "Musician": "موسيقية", "Actor": "ممثلة", "Director": "مخرجة",
    "Photographer": "مُصورة", "Designer": "مصممة", "Writer": "كاتبة", "Editor": "محررة", "Translator": "مترجمة", "IT Specialist": "أخصائية تكنولوجيا المعلومات", "Software Developer": "مطورة برمجيات", "Web Developer": "مطوّرة ويب", "Graphic Designer": "مصممة جرافيك", "Data Analyst": "محللة بيانات",
    "Statistician": "إحصائية", "Cybersecurity Analyst": "محللة أمن سيبراني", "Network Engineer": "مهندسة شبكات", "System Administrator": "مسؤولة أنظمة", "Marketing Specialist": "أخصائية تسويق", "Sales Manager": "مديرة مبيعات", "HR Specialist": "أخصائية موارد بشرية", "Consultant": "مستشارة", "Banker": "موظفة بنك", "Financial Analyst": "محللة مالية",
    "Investment Manager": "مديرة استثمار", "Stockbroker": "سمسارة بورصة", "Insurance Agent": "وكيلة تأمين", "Auditor": "مدققة حسابات", "Public Relations Specialist": "أخصائية علاقات عامة", "Event Planner": "منظمة فعاليات", "Tour Guide": "مرشدة سياحية", "Hotel Manager": "مديرة فندق", "Waiter": "نادلة", "Baker": "خبازة",
    "Butcher": "جزارة", "Fisherman": "صيادة", "Farmer": "مزارعة", "Construction Worker": "عاملة بناء", "Real Estate Agent": "وكيلة عقارات", "Security Guard": "حارسة أمن", "Janitor": "عاملة نظافة", "Tailor": "خياطة", "Shoemaker": "إسكافية", "Barber": "حلاقة",
    "Flight Attendant": "مضيفة طيران", "Ship Captain": "قبطانة سفينة", "Athlete": "رياضية", "Coach": "مدربة", "Referee": "حكمة", "Gym Trainer": "مدربة رياضية", "Priest": "قسيسة", "Imam": "إمامة", "Monk": "راهبة", "Social Worker": "أخصائية اجتماعية",
    "Volunteer": "متطوعة", "Judge": "قاضية", "Politician": "سياسية", "Ambassador": "سفيرة", "Diplomat": "دبلوماسية", "Government Officer": "موظفة حكومية", "Entrepreneur": "رائدة أعمال", "Business Owner": "صاحبة عمل", "Manager": "مديرة", "Supervisor": "مشرفة",
    "Clerk": "كاتبة", "Receptionist": "موظفة استقبال", "Courier": "ساعية", "Delivery Driver": "سائقة توصيل", "Warehouse Worker": "عاملة مستودع", "Logistics Coordinator": "منسقة لوجستية"
}
egyptian_cities = {
    "Cairo": "القاهرة", "Alexandria": "الإسكندرية", "Giza": "الجيزة", "Shubra El Kheima": "شبرا الخيمة", "Port Said": "بورسعيد", "Suez": "السويس", "Luxor": "الأقصر", "Asyut": "أسيوط", "Ismailia": "الإسماعيلية", "Faiyum": "الفيوم",
    "Zagazig": "الزقازيق", "Damietta": "دمياط", "Aswan": "أسوان", "Mansoura": "المنصورة", "Tanta": "طنطا", "Minya": "المنيا", "Beni Suef": "بني سويف", "Hurghada": "الغردقة", "Qena": "قنا", "Sohag": "سوهاج",
    "Sharm El Sheikh": "شرم الشيخ", "Damanhur": "دمنهور", "Banha": "بنها", "Kafr El Sheikh": "كفر الشيخ", "Arish": "العريش", "Mallawi": "ملوي", "Bilharz": "بلحارس", "Marsa Matruh": "مرسى مطروح", "New Cairo": "القاهرة الجديدة", "Obour": "العبور",
    "6th of October City": "مدينة 6 أكتوبر", "Sheikh Zayed City": "مدينة الشيخ زايد", "Madinaty": "مدينتي", "Sadat City": "مدينة السادات", "10th of Ramadan City": "مدينة العاشر من رمضان", "Helwan": "حلوان", "Shibin El Kom": "شبين الكوم", "Desouk": "دسوق", "Qalyub": "قليوب", "Al Mahallah Al Kubra": "المحلة الكبرى",
    "Mit Ghamr": "ميت غمر", "Kafr Saad": "كفر سعد", "Toukh": "طوخ", "Samalut": "سمالوط", "Beni Mazar": "بني مزار", "Abnub": "أبنوب", "El Badari": "البداري", "El Quseir": "القصير", "Ras Gharib": "رأس غارب", "Safaga": "سفاجا",
    "El Alamein": "العلمين", "Matay": "مطاي", "Kom Ombo": "كوم أمبو", "Edku": "إدكو", "Rosetta": "رشيد", "Abu Simbel": "أبو سمبل", "Akhmim": "أخميم", "Farshut": "فرشوط", "Edfu": "إدفو", "Girga": "جرجا"
}
arabic_numerals = ['٠', '١', '٢', '٣', '٤', '٥', '٦', '٧', '٨', '٩']
english_numerals = ['0', '1', '2', '3', '4', '5', '6', '7', '8', '9']
email_ends_withs = ['gmail.com', 'yahoo.com', 'outlook.com', 'hotmail.com', 'aol.com', 'icloud.com', 'protonmail.com', 'zoho.com', 'gmx.com', 'yandex.com']
arabic_genders = ['ذكر', 'أنثي']
english_genders = ['male', 'female']
genders = [*arabic_genders, *english_genders]
male_genders = ['ذكر', 'male']
female_genders = ['أنثي', 'female']
languages = ['ar', 'en',"arabic","english"]
arabic_phone_start_withs = [ '٢',"+٢",""]
english_phone_start_withs = ['2', '+2',""]
phone_start_withs = [*english_phone_start_withs,*arabic_phone_start_withs]
phone_carriers = ['orange', 'we', 'vodafone',"etisalat"]
governorate_map = {
		'01': 'Cairo',
		'02': 'Alexandria',
		'03': 'Port Said',
		'04': 'Suez',
		'11': 'Damietta',
		'12': 'Dakahlia',
		'13': 'Sharqia',
		'14': 'Qalyubia',
		'15': 'Kafr El Sheikh',
		'16': 'Gharbia',
		'17': 'Monufia',
		'18': 'Beheira',
		'19': 'Ismailia',
		'21': 'Giza',
		'22': 'Beni Suef',
		'23': 'Faiyum',
		'24': 'Minya',
		'25': 'Asyut',
		'26': 'Sohag',
		'27': 'Qena',
		'28': 'Aswan',
		'29': 'Luxor',
		'31': 'Red Sea',
		'32': 'New Valley',
		'33': 'Matrouh',
		'34': 'North Sinai',
		'35': 'South Sinai',
	}